Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1323)

Unified Diff: third_party/WebKit/Source/core/events/PointerEventFactory.h

Issue 1976603006: Set view property of pointer events (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebased Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/events/PointerEventFactory.h
diff --git a/third_party/WebKit/Source/core/events/PointerEventFactory.h b/third_party/WebKit/Source/core/events/PointerEventFactory.h
index 08becb5cc8ede705ecfb265f635cbb9fe83ae5b2..feb668e89a3a39243045a30df518430fabe8e077 100644
--- a/third_party/WebKit/Source/core/events/PointerEventFactory.h
+++ b/third_party/WebKit/Source/core/events/PointerEventFactory.h
@@ -37,7 +37,8 @@ public:
PointerEvent* create(const AtomicString& type,
const PlatformTouchPoint&, PlatformEvent::Modifiers,
const FloatSize& pointRadius,
- const FloatPoint& clientPoint);
+ const FloatPoint& clientPoint,
+ DOMWindow*);
PointerEvent* createPointerCancelEvent(
const int pointerId, const WebPointerProperties::PointerType);
@@ -47,8 +48,8 @@ public:
PointerEvent*,
const AtomicString&);
- // For creating transition events (i.e pointerout/leave/over/enter)
- PointerEvent* createPointerTransitionEvent(
+ // For creating boundary events (i.e pointerout/leave/over/enter)
+ PointerEvent* createPointerBoundaryEvent(
PointerEvent*,
const AtomicString&,
EventTarget*);

Powered by Google App Engine
This is Rietveld 408576698